==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/et_EE.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumendid",
"Can't create document" => "Ei suuda dokumenti luua",
"You don't have permission to rename this document" => "Puuduvad õigused dokumendi ümber nimetamiseks",
"Directory saved successfully." => "Kataloog salvestatud edukalt.",
"An error occurred while changing directory." => "Kataloogi vahetamisel tekkis viga.",
"Saved" => "Salvestatud",
"Format filter server is down or misconfigured" => "Formaadi filtri server ei ole saadaval või on valesti seadistatud",
"Conversion failed. Check log for details." => "Muutmine ebaõnnestus. Vaata logidest lisaks.",
"document-styles" => "dokumendi-stiilid",
"document-content" => "dokumendi-sisu",
"bold" => "rasvane",
"italic" => "kaldkiri",
"solid" => "pidev",
"pt" => "pt",
"Saving..." => "Salvestamine...",
"Failed to load documents." => "Dokumentide laadimine ebaõnnestus.",
"No documents were found. Upload or create a document to get started!" => "Ühtegi dokumenti ei leitud. Alustamiseks laadi mõni üles või loo uus dokument!",
"No connection to server. Trying to reconnect." => "Serveriga puudub ühendus. Proovin uuesti ühenduda.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Selle lehe jätmine Redaktori moodi võib põhjustada salvestamata andmete kadu. On soovitav selle asemel kasutada \"Sulge\" nuppu.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Selle dokumendi laadimine ebaõnnestus. Palun kontrolli, kas seda saab avada välise odt redaktoriga. Ühtlasi võib see tähendada, et fail pole jagatud või on hiljuti kustutatud.",
"Save" => "Salvesta",
"Loading documents..." => "Laadin dokumente...",
"'.' is an invalid file name." => "'.' on vigane failinimi.",
"File name cannot be empty." => "Faili nimi ei saa olla tühi.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Vigane nimi, '\\', '/', '<', '>', ':', '\"', '|', '?' ja '*' pole lubatud.",
"Align Left" => "Joonda vasakule",
"Alignment" => "Joondus",
"Align Right" => "Joonda paremale",
"Annotate" => "Annoteeri",
"Background" => "Taust",
"Bold" => "Rasvane",
"Bottom" => "Alla",
"Cancel" => "Loobu",
"Center" => "Keskel",
"Clone" => "Klooni",
"Clone this Style" => "Klooni see stiil",
"Close" => "Sulge",
"Color" => "Värv",
"Create" => "Lisa",
"Decrease Indent" => "Vähenda taanet",
"Default Style" => "Vaikimisi stiil",
"Delete" => "Kustuta",
"Family" => "Pereliikmed",
"Font" => "Kirjatüüp",
"Font Effects" => "Kirjatüübi efektid",
"Format" => "Formaat",
"Increase Indent" => "Suurenda taanet",
"Insert Image" => "Lisa pilt",
"Invite Members" => "Kutsu liikmeid",
"Italic" => "Kaldkiri",
"Justified" => "Joondatud",
"Justify" => "Joonda",
"Left" => "Vasak",
"Loading" => "Laadimine",
"Members" => "Liikmed",
"New Name:" => "Uus nimi:",
"OK" => "OK",
"Open" => "Ava",
"Options" => "Valikud",
"Paragraph..." => "Lõik..",
"Paragraph Styles" => "Lõigu stiilid",
"Redo" => "Tee uuesti",
"Right" => "Parem",
"Size" => "Suurus",
"Spacing" => "Asetus",
"Strikethrough" => "Läbikriipsutus",
"Style" => "Stiil",
"Text" => "Tekst",
"Top" => "Üles",
"Underline" => "Alljoon",
"Undo" => "Ennista",
"Unknown Author" => "Tundmatu autor",
"Edit" => "Muuda",
"Share" => "Jaga",
"guest" => "külaline",
"MS Word support (requires openOffice/libreOffice)" => "MS Word tugi (vajalik OpenOffice/LibreOffice)",
"Local" => "Kohalik",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "Selles serveris on paigaldatud OpenOffice/LibreOffice. Otsinguteed rakenduseni pakutakse läbi preview_libreoffice_path in config.php",
"External" => "Väline",
"openOffice/libreOffice is installed on external server running a format filter server" => "OpenOffice/LibreOffice on paigaldatud välisesse serverisse, millel jookseb formaatide filter server.",
"Disabled" => "Välja lülitatud",
"No MS Word support" => "MS Word tugi puudub",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "Serveri URL",
"Apply and test" => "Rakenda ja testi",
"New document" => "Uus dokument",
"Upload (max. %s)" => "Üleslaadimine (maks. %s)",
"Upload" => "Lae üles",
"Save new documents to" => "Salvesta dokumendid",
"Wrong password. Please retry." => "Vale parool. Palun proovi uuesti.",
"Password" => "Parool",
"Guest %s" => "Külaline %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "See link on aegunud või seda pole kunagi eksisteerinud. Palun võta ühendust inimesega, kes selle sulle jagas.",
"Advanced feature-set" => "Täpsemad seaded",
"(Unstable)" => "(Ebastabiilne)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-app-documents-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/et_EE.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumendid",
"Can't create document" => "Ei suuda dokumenti luua",
"You don't have permission to rename this document" => "Puuduvad õigused dokumendi ümber nimetamiseks",
"Directory saved successfully." => "Kataloog salvestatud edukalt.",
"An error occurred while changing directory." => "Kataloogi vahetamisel tekkis viga.",
"Saved" => "Salvestatud",
"Format filter server is down or misconfigured" => "Formaadi filtri server ei ole saadaval või on valesti seadistatud",
"Conversion failed. Check log for details." => "Muutmine ebaõnnestus. Vaata logidest lisaks.",
"Saving..." => "Salvestamine...",
"Failed to load documents." => "Dokumentide laadimine ebaõnnestus.",
"No documents were found. Upload or create a document to get started!" => "Ühtegi dokumenti ei leitud. Alustamiseks laadi mõni üles või loo uus dokument!",
"No connection to server. Trying to reconnect." => "Serveriga puudub ühendus. Proovin uuesti ühenduda.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Selle lehe jätmine Redaktori moodi võib põhjustada salvestamata andmete kadu. On soovitav selle asemel kasutada \"Sulge\" nuppu.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Selle dokumendi laadimine ebaõnnestus. Palun kontrolli, kas seda saab avada välise odt redaktoriga. Ühtlasi võib see tähendada, et fail pole jagatud või on hiljuti kustutatud.",
"Save" => "Salvesta",
"Loading documents..." => "Laadin dokumente...",
"'.' is an invalid file name." => "'.' on vigane failinimi.",
"File name cannot be empty." => "Faili nimi ei saa olla tühi.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Vigane nimi, '\\', '/', '<', '>', ':', '\"', '|', '?' ja '*' pole lubatud.",
"Align Left" => "Joonda vasakule",
"Alignment" => "Joondus",
"Align Right" => "Joonda paremale",
"Annotate" => "Annoteeri",
"Background" => "Taust",
"Bold" => "Rasvane",
"Bottom" => "Alla",
"Cancel" => "Loobu",
"Center" => "Keskel",
"Clone" => "Klooni",
"Clone this Style" => "Klooni see stiil",
"Close" => "Sulge",
"Color" => "Värv",
"Create" => "Lisa",
"Decrease Indent" => "Vähenda taanet",
"Default Style" => "Vaikimisi stiil",
"Delete" => "Kustuta",
"Family" => "Pereliikmed",
"Font" => "Kirjatüüp",
"Font Effects" => "Kirjatüübi efektid",
"Format" => "Formaat",
"Increase Indent" => "Suurenda taanet",
"Insert Image" => "Lisa pilt",
"Invite Members" => "Kutsu liikmeid",
"Italic" => "Kaldkiri",
"Justified" => "Joondatud",
"Justify" => "Joonda",
"Left" => "Vasak",
"Loading" => "Laadimine",
"Members" => "Liikmed",
"New Name:" => "Uus nimi:",
"OK" => "OK",
"Open" => "Ava",
"Options" => "Valikud",
"Paragraph..." => "Lõik..",
"Paragraph Styles" => "Lõigu stiilid",
"Redo" => "Tee uuesti",
"Right" => "Parem",
"Size" => "Suurus",
"Spacing" => "Asetus",
"Strikethrough" => "Läbikriipsutus",
"Style" => "Stiil",
"Text" => "Tekst",
"Top" => "Üles",
"Underline" => "Alljoon",
"Undo" => "Ennista",
"Unknown Author" => "Tundmatu autor",
"Shared" => "Jagatud",
"Error" => "Tõrge",
"Error while sharing" => "Viga jagamisel",
"Error while unsharing" => "Viga jagamise lõpetamisel",
"Error while changing permissions" => "Viga õiguste muutmisel",
"Shared with you and the group {group} by {owner}" => "Jagatud sinu ja {group} grupiga {owner} poolt",
"Shared with you by {owner}" => "Sinuga jagas {owner}",
"Share with users or groups …" => "Jaga kasutajate või gruppidega ...",
"Share with users, groups or remote users …" => "Jaga kasutajate, gruppide või eemal olevate kasutajatega ...",
"Share" => "Jaga",
"Share link" => "Jaga linki",
"The public link will expire no later than {days} days after it is created" => "Avalik link aegub mitte hiljem kui pärast {days} päeva selle loomist",
"Link" => "Link",
"Password protect" => "Parooliga kaitstud",
"Password" => "Parool",
"Choose a password for the public link" => "Vali avaliku lingi jaoks parool",
"Allow editing" => "Luba muutmine",
"Email link to person" => "Saada link isikule e-postiga",
"Send" => "Saada",
"Set expiration date" => "Määra aegumise kuupäev",
"Expiration" => "Aegumine",
"Expiration date" => "Aegumise kuupäev",
"An error occured. Please try again" => "Tekkis tõrge. Palun proovi uuesti",
"Adding user..." => "Kasutaja lisamine...",
"group" => "grupp",
"Resharing is not allowed" => "Edasijagamine pole lubatud",
"Shared in {item} with {user}" => "Jagatud {item} kasutajaga {user}",
"Unshare" => "Lõpeta jagamine",
"notify by email" => "teavita e-postiga",
"can share" => "saab jagada",
"can edit" => "saab muuta",
"access control" => "ligipääsukontroll",
"create" => "loo",
"change" => "muuda",
"delete" => "kustuta",
"Password protected" => "Parooliga kaitstud",
"Error unsetting expiration date" => "Viga aegumise kuupäeva eemaldamisel",
"Error setting expiration date" => "Viga aegumise kuupäeva määramisel",
"Sending ..." => "Saatmine ...",
"Email sent" => "E-kiri on saadetud",
"Warning" => "Hoiatus",
"Edit" => "Muuda",
"guest" => "külaline",
"MS Word support (requires openOffice/libreOffice)" => "MS Word tugi (vajalik OpenOffice/LibreOffice)",
"Local" => "Kohalik",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "Selles serveris on paigaldatud OpenOffice/LibreOffice. Otsinguteed rakenduseni pakutakse läbi preview_libreoffice_path in config.php",
"External" => "Väline",
"openOffice/libreOffice is installed on external server running a format filter server" => "OpenOffice/LibreOffice on paigaldatud välisesse serverisse, millel jookseb formaatide filter server.",
"Disabled" => "Välja lülitatud",
"No MS Word support" => "MS Word tugi puudub",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "Serveri URL",
"Apply and test" => "Rakenda ja testi",
"New document" => "Uus dokument",
"Upload (max. %s)" => "Üleslaadimine (maks. %s)",
"Upload" => "Lae üles",
"Save new documents to" => "Salvesta dokumendid",
"Wrong password. Please retry." => "Vale parool. Palun proovi uuesti.",
"Guest %s" => "Külaline %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "See link on aegunud või seda pole kunagi eksisteerinud. Palun võta ühendust inimesega, kes selle sulle jagas.",
"Advanced feature-set" => "Täpsemad seaded",
"(Unstable)" => "(Ebastabiilne)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
